@@ -3,3 +3,6 @@ from . import docx
 from . import rtf
 from . import html
 from . import template
+from . import query
+from . import outline
+from . import default
